# Tutorials

The current tutorials stay close to the implemented codebase.

- [1. First Kernel](01-first-kernel.md) boots a local kernel and inspects its channels.
- [2. Publish a Kernel](02-publish-kernel.md) explains how to expose public channels over HTTP.
